@@ -1,6 +1,7 @@
 ;;; tramp-cache.el --- file information caching for Tramp
 
-;; Copyright (C) 2000, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+;; Copyright (C) 2000, 2005, 2006, 2007, 2008,
+;;   2009 Free Software Foundation, Inc.
 
 ;; Author: Daniel Pittman <daniel@inanna.danann.net>
 ;;         Michael Albinus <michael.albinus@gmx.de>
@@ -60,6 +61,7 @@
   (autoload 'tramp-file-name-user "tramp")
   (autoload 'tramp-file-name-host "tramp")
   (autoload 'tramp-file-name-localname "tramp")
+  (autoload 'tramp-run-real-handler "tramp")
   (autoload 'time-stamp-string "time-stamp"))
 
 ;;; -- Cache --
@@ -89,6 +91,9 @@
   :group 'tramp
   :type 'file)
 
+(defvar tramp-cache-data-changed nil
+  "Whether persistent cache data have been changed.")
+
 (defun tramp-get-file-property (vec file property default)
   "Get the PROPERTY of FILE from the cache context of VEC.
 Returns DEFAULT if not set."
@@ -143,7 +148,7 @@ Remove also properties of all files in subdirectories."
 ;; not show proper directory contents when a file has been copied or
 ;; deleted before.
 (defun tramp-flush-file-function ()
-  "Flush all Tramp cache properties from buffer-file-name."
+  "Flush all Tramp cache properties from `buffer-file-name'."
   (let ((bfn (if (stringp (buffer-file-name))
 		 (buffer-file-name)
 	       default-directory)))
@@ -195,6 +200,7 @@ PROPERTY is set persistent when KEY is a vector."
 		  (puthash key (make-hash-table :test 'equal)
 			    tramp-cache-data))))
     (puthash property value hash)
+    (setq tramp-cache-data-changed t)
     ;; This function is called also during initialization of
     ;; tramp-cache.el.  `tramp-message is not defined yet at this
     ;; time, so we ignore the corresponding error.
@@ -211,6 +217,7 @@ KEY identifies the connection, it is either a process or a vector."
   (when (vectorp key)
     (setq key (copy-sequence key))
     (aset key 3 nil))
+  (setq tramp-cache-data-changed t)
   (remhash key tramp-cache-data))
 
 (defun tramp-cache-print (table)
@@ -249,6 +256,7 @@ KEY identifies the connection, it is either a process or a vector."
   (condition-case nil
       (when (and (hash-table-p tramp-cache-data)
 		 (not (zerop (hash-table-count tramp-cache-data)))
+		 tramp-cache-data-changed
 		 (stringp tramp-persistency-file-name))
 	(let ((cache (copy-hash-table tramp-cache-data)))
 	  ;; Remove temporary data.
@@ -289,8 +297,7 @@ KEY identifies the connection, it is either a process or a vector."
 (defun tramp-parse-connection-properties (method)
   "Return a list of (user host) tuples allowed to access for METHOD.
 This function is added always in `tramp-get-completion-function'
-for all methods.  Resulting data are derived from connection
-history."
+for all methods.  Resulting data are derived from connection history."
   (let (res)
     (maphash
      '(lambda (key value)
@@ -314,7 +321,8 @@ history."
 	  (while (setq element (pop list))
 	    (setq key (pop element))
 	    (while (setq item (pop element))
-	      (tramp-set-connection-property key (pop item) (car item))))))
+	      (tramp-set-connection-property key (pop item) (car item)))))
+	(setq tramp-cache-data-changed nil))
     (file-error
      ;; Most likely because the file doesn't exist yet.  No message.
      (clrhash tramp-cache-data))
