@@ -1,17 +1,17 @@
 ;;; tramp-ftp.el --- Tramp convenience functions for Ange-FTP
 
-;; Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007,
-;;   2008 Free Software Foundation, Inc.
+;; Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008,
+;;   2009 Free Software Foundation, Inc.
 
 ;; Author: Michael Albinus <michael.albinus@gmx.de>
 ;; Keywords: comm, processes
 
 ;; This file is part of GNU Emacs.
 
-;; GNU Emacs is free software; you can redistribute it and/or modify
+;; GNU Emacs is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,8 +19,7 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, see
-;; <http://www.gnu.org/licenses/>.
+;; along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -32,7 +31,6 @@
 (require 'tramp)
 (autoload 'tramp-set-connection-property "tramp-cache")
 
-
 (eval-when-compile
 
   ;; Pacify byte-compiler.
@@ -122,6 +120,13 @@ present for backward compatibility."
 ;; If there is URL syntax, `substitute-in-file-name' needs special
 ;; handling.
 (put 'substitute-in-file-name 'ange-ftp 'tramp-handle-substitute-in-file-name)
+(add-hook 'tramp-ftp-unload-hook
+	  '(lambda ()
+	     (setplist 'substitute-in-file-name
+		       (delete 'ange-ftp
+			       (delete 'tramp-handle-substitute-in-file-name
+				       (symbol-plist
+					'substitute-in-file-name))))))
 
 (defun tramp-ftp-file-name-handler (operation &rest args)
   "Invoke the Ange-FTP handler for OPERATION.
@@ -180,7 +185,12 @@ pass to the OPERATION."
 	    (ignore-errors (delete-file tmpfile)))))
 
        ;; Normally, the handlers must be discarded.
-       (t (let* ((inhibit-file-name-handlers
+       ;; `inhibit-file-name-handlers' isn't sufficient, because the
+       ;; local file name could be in Tramp syntax as well (for
+       ;; example, returning VMS file names like "/DISK$CAM:/AAA").
+       ;; That's why we set also `tramp-mode' to nil.
+       (t (let* (;(tramp-mode nil)
+		 (inhibit-file-name-handlers
 		  (list 'tramp-file-name-handler
 			'tramp-completion-file-name-handler
 			(and (eq inhibit-file-name-operation operation)
@@ -206,5 +216,5 @@ pass to the OPERATION."
 ;;   Furthermore, there are no backup files on FTP hosts.
 ;;   Worth further investigations.
 
-;;; arch-tag: 759fb338-5c63-4b99-bd36-b4d59db91cff
+;; arch-tag: 759fb338-5c63-4b99-bd36-b4d59db91cff
 ;;; tramp-ftp.el ends here
